@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -B
-from libsecp256k1 import Secp265k1
+from libsecp256k1_0 import Secp265k1
 
 def test_main():
 	print(Secp265k1._load)
